@@ -3,6 +3,8 @@ from copy import deepcopy
 from typing import TYPE_CHECKING, Any, Dict, Optional, List, Tuple
 
 import pandas as pd
+from mixins import ReprMixin
+
 from datacode.models.column.column import Column
 from pd_utils.optimize.load import read_file
 
@@ -13,7 +15,9 @@ if TYPE_CHECKING:
     from datacode.models.source import DataSource
     from datacode.models.variables.variable import Variable
 
-class DataLoader:
+
+class DataLoader(ReprMixin):
+    repr_cols = ['read_file_kwargs']
 
     def __init__(self, source: 'DataSource', read_file_kwargs: Optional[Dict[str, Any]] = None,
                  optimize_size: bool = False):
@@ -148,7 +152,7 @@ class DataLoader:
         for col_key, dtype in datetime_dtypes.items():
             if isinstance(dtype, DateType):
                 # Remove timestamp portion from date types
-                df[col_key] = df[col_key].dt.floor('d')
+                df[col_key] = df[col_key].dt.date
             elif isinstance(dtype, DatetimeType) and dtype.tz is not None:
                 # Convert to time zone stored in dtype
                 try:
